@@ -5,15 +5,15 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base 2.008 ;
+use IO::Compress::Base 2.009 ;
 
-use IO::Compress::Base::Common  2.008 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Lzf  2.008 ;
+use IO::Compress::Base::Common  2.009 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Lzf  2.009 ;
 #use Compress::Lzf ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $LzfError);
 
-$VERSION = '2.008';
+$VERSION = '2.009';
 $LzfError = '';
 
 @ISA    = qw(Exporter IO::Compress::Base);
@@ -99,7 +99,7 @@ sub getExtraParams
 {
     my $self = shift ;
 
-    use IO::Compress::Base::Common  2.008 qw(:Parse);
+    use IO::Compress::Base::Common  2.009 qw(:Parse);
     
     return (
             'BlockSize' => [0, 1, Parse_unsigned,  (64* 1024) - 1],
@@ -123,8 +123,6 @@ __END__
 
 =head1 NAME
 
-
-
 IO::Compress::Lzf - Write lzf files/buffers
  
  
@@ -133,7 +131,6 @@ IO::Compress::Lzf - Write lzf files/buffers
 
     use IO::Compress::Lzf qw(lzf $LzfError) ;
 
-
     my $status = lzf $input => $output [,OPTS] 
         or die "lzf failed: $LzfError\n";
 
@@ -173,29 +170,17 @@ IO::Compress::Lzf - Write lzf files/buffers
 
 =head1 DESCRIPTION
 
-
 This module provides a Perl interface that allows writing lzf 
 compressed data to files or buffer.
 
-
-
 Note that although this module uses C<Compress::LZF> for compression,
 it uses a different file format.
 The lzf file format used here is the same as the lzf command-line utility
 that ships with the lzf library.
 
-
-
-
-
-
-
-
-
 For reading lzf files/buffers, see the companion module 
 L<IO::Uncompress::UnLzf|IO::Uncompress::UnLzf>.
 
-
 =head1 Functional Interface
 
 A top-level function, C<lzf>, is provided to carry out
@@ -208,14 +193,10 @@ section.
     lzf $input => $output [,OPTS] 
         or die "lzf failed: $LzfError\n";
 
-
-
 The functional interface needs Perl5.005 or better.
 
-
 =head2 lzf $input => $output [, OPTS]
 
-
 C<lzf> expects at least two parameters, C<$input> and C<$output>.
 
 =head3 The C<$input> parameter
@@ -254,8 +235,6 @@ The input data will be read from each file in turn.
 The complete array will be walked to ensure that it only
 contains valid filenames before any data is compressed.
 
-
-
 =item An Input FileGlob string
 
 If C<$input> is a string that is delimited by the characters "<" and ">"
@@ -266,13 +245,10 @@ If the fileglob does not match any files ...
 
 See L<File::GlobMapper|File::GlobMapper> for more details.
 
-
 =back
 
 If the C<$input> parameter is any other type, C<undef> will be returned.
 
-
-
 =head3 The C<$output> parameter
 
 The parameter C<$output> is used to control the destination of the
@@ -292,14 +268,11 @@ If the C<$output> parameter is a filehandle, the compressed data
 will be written to it.
 The string '-' can be used as an alias for standard output.
 
-
 =item A scalar reference 
 
 If C<$output> is a scalar reference, the compressed data will be
 stored in C<$$output>.
 
-
-
 =item An Array Reference
 
 If C<$output> is an array reference, the compressed data will be
@@ -318,21 +291,12 @@ string. Anything else is an error.
 
 If the C<$output> parameter is any other type, C<undef> will be returned.
 
-
-
 =head2 Notes
 
-
-
 When C<$input> maps to multiple files/buffers and C<$output> is a single
 file/buffer the input files/buffers will be stored
 in C<$output> as a concatenated series of compressed data streams.
 
-
-
-
-
-
 =head2 Optional Parameters
 
 Unless specified below, the optional parameters for C<lzf>,
@@ -352,27 +316,18 @@ completed.
 
 This parameter defaults to 0.
 
-
 =item C<< BinModeIn => 0|1 >>
 
 When reading from a file or filehandle, set C<binmode> before reading.
 
 Defaults to 0.
 
-
-
-
-
 =item C<< Append => 0|1 >>
 
 TODO
 
-
-
 =back
 
-
-
 =head2 Examples
 
 To read the contents of the file C<file1.txt> and write the compressed
@@ -386,7 +341,6 @@ data to the file C<file1.txt.lzf>.
     lzf $input => "$input.lzf"
         or die "lzf failed: $LzfError\n";
 
-
 To read from an existing Perl filehandle, C<$input>, and write the
 compressed data to a buffer, C<$buffer>.
 
@@ -424,7 +378,6 @@ and if you want to compress each file one at a time, this will do the trick
             or die "Error compressing '$input': $LzfError\n";
     }
 
-
 =head1 OO Interface
 
 =head2 Constructor
@@ -464,7 +417,6 @@ If the C<$output> parameter is a filehandle, the compressed data will be
 written to it.
 The string '-' can be used as an alias for standard output.
 
-
 =item A scalar reference 
 
 If C<$output> is a scalar reference, the compressed data will be stored
@@ -520,22 +472,10 @@ to it.  Otherwise the file pointer will not be moved.
 
 This parameter defaults to 0.
 
-
-
-
-
-
-
-
-
 =item C<< Strict => 0|1 >>
 
-
-
 This is a placeholder option.
 
-
-
 =back
 
 =head2 Examples
@@ -597,17 +537,12 @@ unsuccessful.
 
 Usage is
 
-
     $z->flush;
 
-
 Flushes any pending compressed data to the output file/buffer.
 
-
-
 Returns true on success.
 
-
 =head2 tell
 
 Usage is
@@ -624,28 +559,19 @@ Usage is
     $z->eof();
     eof($z);
 
-
-
 Returns true if the C<close> method has been called.
 
-
-
 =head2 seek
 
     $z->seek($position, $whence);
     seek($z, $position, $whence);
 
-
-
-
 Provides a sub-set of the C<seek> functionality, with the restriction
 that it is only legal to seek forward in the output file/buffer.
 It is a fatal error to attempt to seek backward.
 
 Empty parts of the file/buffer will have NULL (0x00) bytes written to them.
 
-
-
 The C<$whence> parameter takes one the usual values, namely SEEK_SET,
 SEEK_CUR or SEEK_END.
 
@@ -687,33 +613,27 @@ retrieve the autoflush setting.
     $z->input_line_number()
     $z->input_line_number(EXPR)
 
-
 This method always returns C<undef> when compressing. 
 
-
-
 =head2 fileno
 
     $z->fileno()
     fileno($z)
 
-If the C<$z> object is associated with a file or a filehandle, this method
-will return the underlying file descriptor.
+If the C<$z> object is associated with a file or a filehandle, C<fileno>
+will return the underlying file descriptor. Once the C<close> method is
+called C<fileno> will return C<undef>.
 
-If the C<$z> object is is associated with a buffer, this method will
-return undef.
+If the C<$z> object is is associated with a buffer, this method will return
+C<undef>.
 
 =head2 close
 
     $z->close() ;
     close $z ;
 
-
-
 Flushes any pending compressed data and then closes the output file/buffer. 
 
-
-
 For most versions of Perl this method will be automatically invoked if
 the IO::Compress::Lzf object is destroyed (either explicitly or by the
 variable with the reference to the object going out of scope). The
@@ -732,9 +652,6 @@ If the C<AutoClose> option has been enabled when the IO::Compress::Lzf
 object was created, and the object is associated with a file, the
 underlying file will also be closed.
 
-
-
-
 =head2 newStream([OPTS])
 
 Usage is
@@ -748,20 +665,14 @@ the C<$z> object.
 
 See the L</"Constructor Options"> section for more details.
 
-
-
 =head1 Importing 
 
-
 No symbolic constants are required by this IO::Compress::Lzf at present. 
 
-
-
 =over 5
 
 =item :all
 
-
 Imports C<lzf> and C<$LzfError>.
 Same as doing this
 
@@ -771,21 +682,13 @@ Same as doing this
 
 =back
 
-For 
-
 =head1 EXAMPLES
 
-TODO
-
-
-
-
-
-
-
-
+=head2 Apache::GZip Revisited
 
+See L<IO::Compress::Lzf::FAQ|IO::Compress::Lzf::FAQ/"Apache::GZip Revisited">
 
+    
 
 =head1 SEE ALSO
 
@@ -797,25 +700,18 @@ L<File::GlobMapper|File::GlobMapper>, L<Archive::Zip|Archive::Zip>,
 L<Archive::Tar|Archive::Tar>,
 L<IO::Zlib|IO::Zlib>
 
-
-
-
-
 =head1 AUTHOR
 
 This module was written by Paul Marquess, F<pmqs@cpan.org>. 
 
-
-
 =head1 MODIFICATION HISTORY
 
 See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2007 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2008 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-
